@@ -1,5 +1,5 @@
 from .service import ManagedService
-from .dialog_api import sequence_and_updates_pb2, miscellaneous_pb2
+from dialog_api import sequence_and_updates_pb2, miscellaneous_pb2
 
 DEFAULT_OPTIMIZATIONS = [
     miscellaneous_pb2.UPDATEOPTIMIZATION_STRIP_ENTITIES,
@@ -28,3 +28,12 @@ class Updates(ManagedService):
         )
 
         return diff
+
+    def get_state(self):
+        """Current application seq number
+
+        :return: seq
+        """
+        return self.internal.updates.GetState(sequence_and_updates_pb2.RequestGetState(
+            optimizations=DEFAULT_OPTIMIZATIONS
+        )).seq
